# SaralGyaan Square
It takes an integer as an input and prints it square.

## Installation
```pip install saral-square```

## How to use it?
Open terminal and type square and then input the integer

## License

© 2020 Udit Vashisht

This repository is licensed under the MIT license. See LICENSE for details.
